@@ -1,5 +1,5 @@
+use std::borrow::Borrow;
 use std::sync::atomic::AtomicI32;
-use may::sync::mpsc::{Receiver, Sender};
 use log::{Level, Metadata, Record};
 use parking_lot::RwLock;
 
@@ -15,7 +15,8 @@ use std::result::Result::Ok;
 use std::time::{SystemTime, Duration};
 use std::sync::Arc;
 use std::sync::mpsc::SendError;
-use may::go;
+use cogo::coroutine::yield_now;
+use cogo::go;
 
 lazy_static! {
     static ref LOG_SENDER: RwLock<Option<LoggerSender>> = RwLock::new(Option::None);
@@ -75,7 +76,7 @@ impl log::Log for Logger {
         if let Some(sender) = LOG_SENDER.read().as_ref() {
             if !sender.filter.filter(record) {
                 if let Some(v) = record.module_path() {
-                    if v == "may::io::sys::select" {
+                    if v == "cogo::io::sys::select" {
                         return;
                     }
                 }
@@ -132,6 +133,7 @@ pub fn init_log(
 /// allow_zip_compress: zip compress log file
 /// filter: log filter
 /// packer: you can use ZipPacker or LZ4Packer or custom your Packer
+/// temp is "temp.log"
 pub fn init_split_log(
     log_dir_path: &str,
     max_temp_size: LogSize,
@@ -145,7 +147,6 @@ pub fn init_split_log(
         log_dir_path,
         max_temp_size,
         rolling_type,
-        1,
         packer,
     ))];
     if allow_console_log {
@@ -174,42 +175,68 @@ pub fn init_custom_log(
     }
     let wait_group = FastLogWaitGroup::new();
     let main_recv = set_log(level, filter);
-    let (back_sender, back_recv) = may::sync::mpsc::channel();
     //main recv data
-    let wait_group_main = wait_group.clone();
-    go!(move ||{
-        loop {
-            let data = main_recv.recv();
-            if data.is_ok() {
-                let mut s: FastLogRecord = data.unwrap();
-                if s.command.eq(&Command::CommandExit) {
-                    back_sender.send(s);
-                    drop(wait_group_main);
-                    break;
+    let wait_group_back = wait_group.clone();
+    std::thread::spawn(move || {
+        let mut recever_vec = vec![];
+        let mut sender_vec: Vec<cogo::std::channel::Sender<Arc<FastLogRecord>>> = vec![];
+        for a in appenders {
+            let (s, r) = cogo::std::sync::mpsc::channel();
+            sender_vec.push(s);
+            recever_vec.push((r, a));
+        }
+        for (recever, appender) in recever_vec {
+            let current_wait_group = wait_group_back.clone();
+            if appender.type_name().starts_with("fast_log::plugin") {
+                // if is file appender, use thread spawn
+                std::thread::spawn(move || {
+                    loop {
+                        if let Ok(msg) = recever.recv() {
+                            if msg.command.eq(&Command::CommandExit) {
+                                drop(current_wait_group);
+                                break;
+                            }
+                            appender.do_log(msg.as_ref());
+                        } else {
+                            yield_now();
+                        }
+                    }
+                });
+            } else {
+                // if is network appender, use thread spawn
+                go!(move ||{
+                loop{
+                    if let Ok(msg) = recever.recv(){
+                     if msg.command.eq(&Command::CommandExit) {
+                        drop(current_wait_group);
+                        break;
+                     }
+                     appender.do_log(msg.as_ref());
+                    }else{
+                        yield_now();
+                    }
                 }
-                back_sender.send(s);
+            });
             }
         }
-    });
-    let wait_group_back = wait_group.clone();
-    //back recv data
-    go!(move || {
         loop {
             //recv
-            let data = back_recv.recv();
+            let data = main_recv.recv();
             if let Ok(mut data) = data {
-                if data.command.eq(&Command::CommandExit){
+                data.formated = format.do_format(&mut data);
+                let data = Arc::new(data);
+                for x in &sender_vec {
+                    x.send(data.clone());
+                }
+                if data.command.eq(&Command::CommandExit) {
                     drop(wait_group_back);
                     break;
                 }
-                data.formated = format.do_format(&mut data);
-                for x in &appenders {
-                    x.do_log(&mut data);
-                }
+            } else {
+                yield_now();
             }
         }
     });
-
     let r = log::set_logger(&LOGGER).map(|()| log::set_max_level(level.to_level_filter()));
     if r.is_err() {
         return Err(LogError::from(r.err().unwrap()));
@@ -226,12 +253,12 @@ pub fn exit() -> Result<(), LogError> {
             command: Command::CommandExit,
             level: log::Level::Info,
             target: String::new(),
-            args: "exit".to_string(),
+            args: String::new(),
             module_path: String::new(),
             file: String::new(),
             line: None,
             now: SystemTime::now(),
-            formated: "exit".to_string(),
+            formated: String::new(),
         };
         let result = sender.send(fast_log_record);
         match result {
@@ -254,12 +281,12 @@ pub fn flush() -> Result<(), LogError> {
             command: Command::CommandFlush,
             level: log::Level::Info,
             target: String::new(),
-            args: "flush".to_string(),
+            args: String::new(),
             module_path: String::new(),
             file: String::new(),
             line: None,
             now: SystemTime::now(),
-            formated: "flush".to_string(),
+            formated: String::new(),
         };
         let result = sender.send(fast_log_record);
         match result {
