@@ -9,8 +9,9 @@ use crate::appender::{Command, FastLogRecord, LogAppender};
 use crate::consts::LogSize;
 use std::ops::Sub;
 use std::time::Duration;
-use may::go;
-use may::sync::mpsc::{Receiver, Sender};
+use cogo::go;
+use cogo::std::channel::{Receiver, Sender};
+
 use zip::result::ZipResult;
 use crate::error::LogError;
 
@@ -38,13 +39,19 @@ pub struct LogPack {
 ///rolling keep type
 #[derive(Copy, Clone, Debug)]
 pub enum RollingType {
+    /// keep All of log packs
     All,
+    /// keep by Time Duration,
+    /// for example:
+    /// // keep one day log pack
+    /// (Duration::from_secs(24 * 3600))
     KeepTime(Duration),
+    /// keep log pack num(.log,.zip.lz4...more)
     KeepNum(i64),
 }
 
 impl RollingType {
-    fn read_paths(&self, dir: &str) -> Vec<DirEntry> {
+    fn read_paths(&self, dir: &str, temp_name: &str) -> Vec<DirEntry> {
         let paths = std::fs::read_dir(dir);
         if let Ok(paths) = paths {
             let mut paths_vec = vec![];
@@ -53,7 +60,7 @@ impl RollingType {
                     Ok(path) => {
                         if let Some(v) = path.file_name().to_str() {
                             //filter temp.log and not start with temp
-                            if v.ends_with("temp.log") || !v.starts_with("temp") {
+                            if (v.ends_with(".log") && v.trim_end_matches(".log").ends_with(temp_name)) || !v.starts_with(temp_name) {
                                 continue;
                             }
                         }
@@ -68,10 +75,10 @@ impl RollingType {
         return vec![];
     }
 
-    pub fn do_rolling(&self, dir: &str) {
+    pub fn do_rolling(&self, temp_name: &str, dir: &str) {
         match self {
             RollingType::KeepNum(n) => {
-                let paths_vec = self.read_paths(dir);
+                let paths_vec = self.read_paths(dir, temp_name);
                 for index in 0..paths_vec.len() {
                     if index >= *n as usize {
                         let item = &paths_vec[index];
@@ -80,7 +87,7 @@ impl RollingType {
                 }
             }
             RollingType::KeepTime(t) => {
-                let paths_vec = self.read_paths(dir);
+                let paths_vec = self.read_paths(dir, temp_name);
                 let duration = chrono::Duration::from_std(t.clone());
                 if duration.is_err() {
                     return;
@@ -91,7 +98,7 @@ impl RollingType {
                     let item = &paths_vec[index];
                     let file_name = item.file_name();
                     let name = file_name.to_str().unwrap_or("").to_string();
-                    if let Some(time) = self.file_name_parse_time(&name) {
+                    if let Some(time) = self.file_name_parse_time(&name, temp_name) {
                         if now.sub(time) > duration {
                             std::fs::remove_file(item.path());
                         }
@@ -102,9 +109,9 @@ impl RollingType {
         }
     }
 
-    fn file_name_parse_time(&self, name: &str) -> Option<NaiveDateTime> {
-        if name.starts_with("temp") {
-            let mut time_str = name.replace("temp", "");
+    fn file_name_parse_time(&self, name: &str, temp_name: &str) -> Option<NaiveDateTime> {
+        if name.starts_with(temp_name) {
+            let mut time_str = name.replace(temp_name, "");
             if let Some(v) = time_str.find(".") {
                 time_str = time_str[0..v].to_string();
             }
@@ -127,15 +134,16 @@ pub struct FileSplitAppenderData {
     rolling_type: RollingType,
     //cache data
     temp_bytes: usize,
+    temp_name: String,
 }
 
 impl FileSplitAppenderData {
     pub fn send_pack(&mut self) {
-        let first_file_path = format!("{}{}.log", self.dir_path, "temp");
+        let first_file_path = format!("{}{}.log", self.dir_path, &self.temp_name);
         let new_log_name = format!(
             "{}{}{}.log",
             self.dir_path,
-            "temp",
+            &self.temp_name,
             format!("{:29}", Local::now().format("%Y_%m_%dT%H_%M_%S%.f")).replace(" ", "_")
         );
         std::fs::copy(&first_file_path, &new_log_name);
@@ -157,16 +165,26 @@ impl FileSplitAppenderData {
 
 impl FileSplitAppender {
     ///split_log_bytes:  log file data bytes(MB) splite
-    ///dir_path:         the log dir
+    ///file_path:         the log dir or file name
     ///log_pack_cap:     pack(zip,lz4 or more...) or log Waiting cap
     /// packer: default is zip packer
     pub fn new(
-        dir_path: &str,
+        file_path: &str,
         max_temp_size: LogSize,
         rolling_type: RollingType,
-        log_pack_cap: usize,
         packer: Box<dyn Packer>,
     ) -> FileSplitAppender {
+        let mut dir_path = file_path.to_owned();
+        let mut temp_file_name = dir_path.to_string();
+        if dir_path.contains("/"){
+            let new_dir_path = dir_path[0..dir_path.rfind("/").unwrap_or_default()].to_string()+"/";
+            std::fs::create_dir_all(&new_dir_path);
+            temp_file_name = dir_path.trim_start_matches(&new_dir_path).to_string();
+            dir_path = new_dir_path;
+        }
+        if temp_file_name.is_empty(){
+            temp_file_name = "temp.log".to_string();
+        }
         if !dir_path.is_empty() && dir_path.ends_with(".log") {
             panic!("FileCompactionAppender only support new from path,for example: 'logs/xx/'");
         }
@@ -174,9 +192,10 @@ impl FileSplitAppender {
             panic!("FileCompactionAppender only support new from path,for example: 'logs/xx/'");
         }
         if !dir_path.is_empty() {
-            std::fs::create_dir_all(dir_path);
+            std::fs::create_dir_all(&dir_path);
         }
-        let first_file_path = format!("{}{}.log", dir_path, "temp");
+        let mut file_name = temp_file_name.trim_end_matches(".log");
+        let first_file_path = format!("{}{}.log", &dir_path, file_name);
         let file = OpenOptions::new()
             .create(true)
             .read(true)
@@ -194,8 +213,8 @@ impl FileSplitAppender {
             temp_bytes = m.len() as usize;
         }
         file.seek(SeekFrom::Start(temp_bytes as u64));
-        let (sender, receiver) = may::sync::mpsc::channel();
-        spawn_saver(receiver, packer);
+        let (sender, receiver) = cogo::std::sync::mpsc::channel();
+        spawn_saver(file_name,receiver, packer);
         Self {
             cell: RefCell::new(FileSplitAppenderData {
                 max_split_bytes: max_temp_size.get_len(),
@@ -204,13 +223,14 @@ impl FileSplitAppender {
                 file: file,
                 sender: sender,
                 rolling_type: rolling_type,
+                temp_name: file_name.to_string()
             }),
         }
     }
 }
 
 impl LogAppender for FileSplitAppender {
-    fn do_log(&self, record: &mut FastLogRecord) {
+    fn do_log(&self, record: &FastLogRecord) {
         let mut data = self.cell.borrow_mut();
         if record.command.eq(&Command::CommandFlush) || (data.temp_bytes >= data.max_split_bytes) {
             data.send_pack();
@@ -227,12 +247,13 @@ impl LogAppender for FileSplitAppender {
 }
 
 ///spawn an saver thread to save log file or zip file
-fn spawn_saver(r: Receiver<LogPack>, packer: Box<dyn Packer>) {
+fn spawn_saver(temp_name: &str, r: Receiver<LogPack>, packer: Box<dyn Packer>) {
+    let temp = temp_name.to_string();
     std::thread::spawn(move || {
         loop {
             if let Ok(pack) = r.recv() {
                 //do rolling
-                pack.rolling.do_rolling(&pack.dir);
+                pack.rolling.do_rolling(&temp, &pack.dir);
                 let log_file_path = pack.new_log_name.clone();
                 //do save pack
                 let remove = do_pack(&packer, pack);
